@@ -73,6 +73,12 @@ has 'extra_sge_args_string' => (
 	default => ''
 );
 
+has 'memory_too_small' => (
+	is      => 'ro',
+	isa     => 'CodeRef',
+	default => sub { return sub { return 0 } }
+);
+
 sub _analyse_completion_state {
 	my $self  = shift;
 	my $run   = shift;
@@ -156,9 +162,12 @@ sub _vmem_usage {
 	my $loglevel = $warn ? 'warn' : 'info';
 	$self->$loglevel( sprintf "Resource(%s): Requested(%s) Usage(%s) %.2f%%%s",
 		'h_vmem', $dreq, $dused, $pct, $warn );
-	my $cmd  = "tail -1 " . $run->_stderr;
+	my $stderr = $run->_stderr;
+	my $cmd  = "tail -1 $stderr";
 	my $last = `$cmd`;
-	if ($last =~ /Out of memory\!/ || $pct >= 99) {
+	if ($last =~ /Out of memory\!/
+			|| $pct >= 99
+			|| $self->memory_too_small->($stats, $stderr)) {
 		return $self->_can_retry_from_vmem(
 			$pct > 100
 				? ( $used, $dused )
